import React from 'react';
import { useAppDispatch, useML } from '@graphpolaris/shared/lib/data-access';
import {
  setCentralityEnabled,
  setCommunityDetectionEnabled,
  setLinkPredictionEnabled,
  setShortestPathEnabled,
} from '@graphpolaris/shared/lib/data-access/store/mlSlice';
import { FormDiv, FormCard, FormBody, FormTitle, FormHBar } from '@graphpolaris/shared/lib/components/forms';
import { Input } from '@graphpolaris/shared/lib/components/inputs';
import { PopoverTrigger } from '@graphpolaris/shared/lib/components/layout/Popover';

export const QueryMLDialog = () => {
  const dispatch = useAppDispatch();
  const ml = useML();

  return (
    <div>
      <FormCard>
        <FormBody
          onSubmit={(e) => {
            e.preventDefault();
          }}
        >
          <FormTitle title="Machine Learning Options" />
          <FormHBar />

          <div className="px-5">
            <Input
              type="boolean"
              label="Link Prediction"
              value={ml.linkPrediction.enabled}
              onChange={() => dispatch(setLinkPredictionEnabled(!ml.linkPrediction.enabled))}
            />
            {ml.linkPrediction.enabled && ml.linkPrediction.result && <span># of predictions: {ml.linkPrediction.result.length}</span>}
            {ml.linkPrediction.enabled && !ml.linkPrediction.result && <span>Loading...</span>}

            <Input
              type="boolean"
              label="Centrality"
              value={ml.centrality.enabled}
              onChange={() => dispatch(setCentralityEnabled(!ml.centrality.enabled))}
            />
            {ml.centrality.enabled && Object.values(ml.centrality.result).length > 0 && (
              <span>
                sum of centers:
                {Object.values(ml.centrality.result)
                  .reduce((a, b) => b + a)
                  .toFixed(2)}
              </span>
            )}
            {ml.centrality.enabled && Object.values(ml.centrality.result).length === 0 && <span>No Centers Found</span>}

            <Input
              type="boolean"
              label="Community detection"
              value={ml.communityDetection.enabled}
              onChange={() => dispatch(setCommunityDetectionEnabled(!ml.communityDetection.enabled))}
            />
            {ml.communityDetection.enabled && ml.communityDetection.result && (
              <span># of communities: {ml.communityDetection.result.length}</span>
            )}
            {ml.communityDetection.enabled && !ml.communityDetection.result && <span>Loading...</span>}

            <Input
              type="boolean"
              label="Shortest path"
              value={ml.shortestPath.enabled}
              onChange={() => dispatch(setShortestPathEnabled(!ml.shortestPath.enabled))}
            />
            {ml.shortestPath.enabled && ml.shortestPath.result?.length > 0 && <span># of hops: {ml.shortestPath.result.length}</span>}
            {ml.shortestPath.enabled && !ml.shortestPath.srcNode && <span>Please select source node</span>}
            {ml.shortestPath.enabled && ml.shortestPath.srcNode && !ml.shortestPath.trtNode && <span>Please select target node</span>}
          </div>
        </FormBody>
      </FormCard>
    </div>
  );
};
