import React, { useMemo } from 'react';
import { useGraphQueryResult, useQuerybuilderGraph } from '@graphpolaris/shared/lib/data-access';
import VisualizationBar from './bar';
import { VisualizationManager, VisualizationManagerType } from '../manager';
import { Recommender, NoData, Querying } from '../views';
import { resultSetFocus } from '../../data-access/store/interactionSlice';
import { useDispatch } from 'react-redux';

export const VisualizationPanel = ({ fullSize }: { fullSize: () => void }) => {
  const manager = VisualizationManager();
  const query = useQuerybuilderGraph();
  const graphQueryResult = useGraphQueryResult();
  const dispatch = useDispatch();

  const renderContent = useMemo(() => {
    if (graphQueryResult.queryingBackend) {
      return <Querying />;
    } else if (graphQueryResult.nodes.length === 0) {
      return <NoData dataAvailable={query.nodes.length > 0} />;
    } else if (manager.tabs.length === 0) {
      return <Recommender onClick={(id: string) => manager.changeActive(id)} />;
    }
    return <div className="w-full h-full flex">{manager.renderComponent()}</div>;
  }, [graphQueryResult, manager]);

  return (
    <div
      className="vis-panel h-full w-full flex flex-col border bg-light"
      onMouseDownCapture={() => dispatch(resultSetFocus({ focusType: 'visualization' }))}
    >
      <VisualizationBar manager={manager} fullSize={fullSize} />
      <div className="grow overflow-y-auto" style={graphQueryResult.nodes.length === 0 ? { overflow: 'hidden' } : {}}>
        {renderContent}
      </div>
    </div>
  );
};
